
# Topsis Python Implementation

*for*: Assignment 1(UCS654) submitted by: Vyom Kapur; Roll number: 102053010; Group: 3COE18

Topsis is the Technique for Order of Preference by Similarity to Ideal Solution, is used for dealing with Multiple Criteria Decision Making (MCDM) problems.


## Installation

Install Topsis with pip as: 

```bash
  pip install topsis-vyom-10253010
```

## Usage/Examples
Enter csv filename followed by .csv extentsion, then enter the weights vector with vector values separated by commas, followed by the impacts vector with comma separated signs (+,-)

```bash
  topsis sample.csv "1,1,1,1" "+,-,+,+"
```


## License

[MIT](https://choosealicense.com/licenses/mit/)

